From e62346c9ba9b27ecf8c7b322ac9d7a4bb25bca48 Mon Sep 17 00:00:00 2001
From: alecpl <alec@alec.pl>
Date: Thu, 25 Feb 2010 07:43:21 -0500
Subject: [PATCH] - Fix encoding of Return-Receipt-To and Disposition-Notification-To headers (1486515)

---
 program/lib/Mail/mime.php |   25 +++++--------------------
 1 files changed, 5 insertions(+), 20 deletions(-)

diff --git a/program/lib/Mail/mime.php b/program/lib/Mail/mime.php
index 81a2569..d6d63d6 100644
--- a/program/lib/Mail/mime.php
+++ b/program/lib/Mail/mime.php
@@ -111,22 +111,6 @@
     var $_htmlbody;
 
     /**
-     * contains the mime encoded text
-     *
-     * @var string
-     * @access private
-     */
-    var $_mime;
-
-    /**
-     * contains the multipart content
-     *
-     * @var string
-     * @access private
-     */
-    var $_multipart;
-
-    /**
      * list of the attached images
      *
      * @var array
@@ -1037,7 +1021,7 @@
      *
      * @param array $xtra_headers Assoc array with any extra headers (optional)
      * @param bool  $overwrite    Overwrite already existing headers.
-     * @param bool  $skip_content Don't return content headers: Content-Type
+     * @param bool  $skip_content Don't return content headers: Content-Type,
      *                            Content-Disposition and Content-Transfer-Encoding
      * 
      * @return array              Assoc array with the mime headers
@@ -1083,9 +1067,9 @@
      * (usefull if you want to use the PHP mail() function)
      *
      * @param array $xtra_headers Assoc array with any extra headers (optional)
      * @param bool  $overwrite    Overwrite the existing heaers with new.
      * @param bool  $skip_content Don't return content headers: Content-Type
      *                            and Content-Transfer-Encoding
      *
      * @return string             Plain text headers
      * @access public
@@ -1254,6 +1238,7 @@
             'from', 'to', 'cc', 'bcc', 'sender', 'reply-to',
             'resent-from', 'resent-to', 'resent-cc', 'resent-bcc',
             'resent-sender', 'resent-reply-to',
+	    'return-receipt-to', 'disposition-notification-to',
         );
         $other_headers = array(
             'references', 'in-reply-to', 'message-id', 'resent-message-id',
@@ -1083,9 +1067,9 @@
      *
      * @param array $xtra_headers Assoc array with any extra headers (optional)
-     * @param bool  $overwrite    Overwrite the existing heaers with new.
-     * @param bool  $skip_content Don't return content headers: Content-Type
-     *                            and Content-Transfer-Encoding
+     * @param bool  $overwrite    Overwrite the existing headers with new.
+     * @param bool  $skip_content Don't return content headers: Content-Type,
+     *                            Content-Disposition and Content-Transfer-Encoding
      *
      * @return string             Plain text headers

--
Gitblit v1.9.1